<script setup>
import { ref, reactive } from "vue";
import { changeSnId } from "./api";
import { useRouter, useRoute } from "vue-router";
import { ElMessage } from "element-plus";
const $message = ElMessage;

const router = useRouter();

const ruleForm = ref();
const emit = defineEmits(["update:visible"]);
const props = defineProps({
  visible: {
    type: Boolean,
    default: false,
  },
  name: {
    type: String,
    default: "",
  },
});
const params = reactive({
  userName: "",
  oldPwd: "",
  newPwd: "",
  enPwd: "",
});
const rules = {
  oldPwd: [{ required: true, message: "不能为空", trigger: "blur" }],
  newPwd: [
    { required: true, message: "不能为空", trigger: "blur" },
    // { validator: validatePass, trigger: 'blur' }
  ],
  enPwd: [
    { required: true, message: "不能为空", trigger: "blur" },
    // { validator: validatePass, trigger: 'blur' }
  ],
};

// 提交表单
function submitForm() {
  ruleForm.value.validate((valid) => {
    // 校验通过
    if (valid) {
      checkUserPword();
    } else {
      // $layer.msg('存在校验未通过的数据！');
      return false;
    }
  });
}
function checkUserPword() {
  if (params.newPwd !== params.enPwd) {
    $message.error("新密码和确认密码不一致");
    return false;
  }
  // 校验用户的密码
  changeSnId(params.newPwd, params.oldPwd)
    .then((res) => {
      let { code, data, msg } = res.data;
      if (code && data) {
        $message.success("操作成功, 请重新登录");
        localStorage.removeItem("uname");
        localStorage.removeItem("uid");
        router.push("/login");
      } else {
        $message.error(msg);
      }
    })
    .catch((error) => {
      console.log(error);
    });
}
function close() {
  emit("update:visible", false);
}
</script>

<template>
  <div class="params-container">
    <el-form
      ref="ruleForm"
      size="small"
      label-position="top"
      :model="params"
      :rules="rules"
      class="params-dialog"
    >
      <el-form-item label="旧密码" prop="oldPwd">
        <el-input type="password" v-model="params.oldPwd"></el-input>
      </el-form-item>
      <el-form-item label="新密码" prop="newPwd">
        <el-input
          type="password"
          v-model="params.newPwd"
          show-password
        ></el-input>
      </el-form-item>
      <el-form-item label="确认密码" prop="enPwd">
        <el-input
          type="password"
          v-model="params.enPwd"
          show-password
        ></el-input>
      </el-form-item>
      <div class="form-footer">
        <three-btn @click="submitForm">确定</three-btn>
        <three-btn @click="close">取消</three-btn>
      </div>
    </el-form>
  </div>
</template>

<style scoped lang="less">
.params-container {
  padding: 8px;
  background-color: #ececec;
}
.form-footer {
  margin-top: 16px;
  margin-bottom: 16px;
  text-align: right;
}

.form-footer .three-btn {
  margin-left: 12px;
}
:deep(.el-input__icon.el-icon-view.el-input__clear) {
  color: #ffffff;
}
</style>
